@@ -4,13 +4,9 @@ package SNMP::Class;
 
 SNMP::Class - A convenience class around the NetSNMP perl modules. 
 
-=head1 VERSION
-
-Version 0.09
-
 =cut
 
-use version; our $VERSION = qv('0.10.00');
+our $VERSION = '0.05';
 
 =head1 SYNOPSIS
 
@@ -32,11 +28,6 @@ This module aims to enable snmp-related tasks to be carried out with the best po
 	my $if_descr_3 = $ifTable->object("ifDescr")->instance("3");
 	#more compact
 	my $if_descr_3 = $ifTable->object(ifDescr).3;
-
-	#iterate over interface descriptions -- method senses list context and returns array
-	for my $descr ($ifTable->object"ifDescr")) { 
-		print $descr->get_value,"\n";
-	}
 	
 	#get the speed of the instance for which ifDescr is en0
 	my $en0_speed = $ifTable->find("ifDescr","en0")->object("ifSpeed")->get_value;  
@@ -54,7 +45,6 @@ This module aims to enable snmp-related tasks to be carried out with the best po
 use warnings;
 use strict;
 use Carp;
-use Carp::Assert;
 use Data::Dumper;
 use SNMP;
 use SNMP::Class::ResultSet;
@@ -62,21 +52,16 @@ use SNMP::Class::Varbind;
 use SNMP::Class::OID;
 use SNMP::Class::Utils;
 use Class::Std;
-
 use Log::Log4perl qw(:easy);
-Log::Log4perl->easy_init({
-	level=>$DEBUG,
-	layout => "%M:%L %m%n",
-});
+
+Log::Log4perl->easy_init($DEBUG);
 my $logger = get_logger();
 
-####&SNMP::loadModules('ALL');
+
+my (%session,%name,%version,%community) : ATTRS;
 
 
-my (%session,%name,%version,%community,%deactivate_bulkwalks) : ATTRS;
-
-
-=head2 new({DestHost=>$desthost,Community=>$community,Version=>$version,DestPort=>$port})
+=head2 new({DestHost=>$desthost,Community=>$community,Version=>$version})
 
 This method creates a new session with a managed device. At this point Version can only be 1 or 2. If Version is not present, the library will try to probe by querying sysName.0 from the device using version 2 and then version 1, whichever succeeds first. This method croaks if a session cannot be created. If the managed node cannot return the sysName.0 object, the method will also croak. 
 
@@ -90,7 +75,6 @@ sub BUILD {
 	my $session;
 	my @versions = ( $arg_ref->{Version} );
 
-
 	#if the user did not specify a version, then we will try one after the other
 	if ( !defined($arg_ref->{Version})) {
 		@versions = ( "2" , "1" );
@@ -101,26 +85,12 @@ sub BUILD {
 		$arg_ref->{Community} = "public";
 	}	
 
-	if (!defined($arg_ref->{RemotePort})) {
-		$logger->debug("setting port to default (161)");
-		$arg_ref->{RemotePort} = 161;
-	}
-
 	$logger->info("Host is $arg_ref->{DestHost}, community is $arg_ref->{Community}");
 	
 	for my $version (@versions) {
 		$logger->debug("trying version $version");
-		
-		#set $arg_ref->{Version} to $version
-		$arg_ref->{Version}=$version;
-
-		#construct a string for debug purposes and log it
-		my $debug_str = join(",",map( "$_=>$arg_ref->{$_}", (keys %{$arg_ref})));
-		$logger->debug("doing SNMP::Session->new($debug_str)");
-
-		#construct the arguments we will be passing to SNMP::Session->new
-		my @argument_array = map { $_ => $arg_ref->{$_}  } (keys %{$arg_ref});
-		$session{$obj_ID} = SNMP::Session->new(@argument_array);
+		$logger->debug("doing SNMP::Session->new(DestHost => $arg_ref->{DestHost},Version => $version ,Community => $arg_ref->{Community})");
+		$session{$obj_ID} = SNMP::Session->new(DestHost => $arg_ref->{DestHost},Version => $version ,Community => $arg_ref->{Community});
 		if(!$session{$obj_ID}) {
 			$logger->debug("null session. Next.");
 		}
@@ -148,19 +118,6 @@ sub BUILD {
 
 }
 
-=head2 deactivate_bulkwalks
-
-If called, this method will permanently deactivate usage of bulkwalk for the session. Mostly useful for broken agents, some buggy versions of Net-SNMP etc. 
-=cut
-
-sub deactivate_bulkwalks {
-	my $self = shift(@_) or croak "deactivate_bulkwalks called outside of an object context";
-	my $id = ident $self;
-	$deactivate_bulkwalks{$id} = 1 ;
-	return;	
-}
-
-
 sub getOid :RESTRICTED() {
 	
 	my $self = shift(@_) or croak "getvar called outside of an object context";
@@ -181,18 +138,6 @@ sub getOid :RESTRICTED() {
 	return $a[0];
 }
 
-=head2 getSysName
-
-Returns the sysname of the machine corresponding to the session
-
-=cut
-
-sub get_name {
-	my $self = shift(@_) or confess "incorrect call";
-	my $id = ident $self;
-	return $name{$id};
-}
-
 
 =head2 getVersion
 
@@ -220,12 +165,8 @@ One should probably also take a look at L<SNMP::Class::ResultSet> pod to see wha
 #normal snmpwalk, or, in the case of SNMPv2c, bulkwalk.
 sub walk {
 	my $self = shift(@_) or confess "sub walk called outside of an object context";
-	my $id = ident $self;
+	####my $id = ident $self;
 	my $oid_name = shift(@_) or confess "First argument missing in call to get_data";
-	
-	if ($deactivate_bulkwalks{$id}) { 
-		return $self->_walk($oid_name);
-	}
 
 	if ($self->getVersion > 1) {
 		return $self->bulk($oid_name);
@@ -245,9 +186,7 @@ sub bulk:RESTRICTED() {
 	$logger->debug("Object to bulkwalk is ".$oid->to_string);
 
 	#create the varbind
-	#was: my $vb = SNMP::Class::Varbind->new($oid) or confess "cannot create new varbind for $oid";
-	my $vb = SNMP::Class::Varbind->new($oid);
-	should(ref $vb,'SNMP::Class::Varbind');
+	my $vb = SNMP::Class::Varbind->new($oid) or confess "cannot create new varbind for $oid";
 
 	#create the bag
 	my $ret = SNMP::Class::ResultSet->new();
@@ -262,14 +201,14 @@ sub bulk:RESTRICTED() {
 	my ($temp) = $session{$id}->bulkwalk(0,10,$vb->get_varbind); #magic number 10 for the time being
 	#make sure nothing went wrong
 	confess $session{$id}->{ErrorStr} if ($session{$id}->{ErrorNum} != 0);
-
+	
 	####my $ret;
 	for my $object (@{$temp}) {
 		###my ($oid_name,$instance,$value,$type) = @{$object};
 		###print Dumper($object);
 		my $vb = SNMP::Class::Varbind->new_from_varbind($object);
 		
-		$logger->debug($vb->get_oid->to_string."=".$vb->get_value." Object is ".$vb->get_object->to_string.",instance is ".$vb->get_instance_numeric.",type is ".$vb->get_type);
+		$logger->debug($vb->get_oid->to_string."=".$vb->get_value." Object is ".$vb->get_object->to_string.",instance is ".$vb->get_instance_numeric);
 		
 		#put it in the bag
 		$ret->push($vb);
@@ -279,7 +218,7 @@ sub bulk:RESTRICTED() {
 
 
 #does an snmpwalk on the session object
-sub _walk:RESTICTED() {
+sub _walk {
 	my $self = shift(@_) or confess "Incorrect call to _walk, self argument missing";
 	my $id = ident $self;
 	my $oid = shift(@_) or confess "First argument missing in call to get_data";
@@ -294,9 +233,7 @@ sub _walk:RESTICTED() {
 	my $previous = SNMP::Class::OID->new("0.0");##let's just assume that no oid can ever be 0.0
 
 	#create the varbind
-	#was: my $vb = SNMP::Class::Varbind->new($oid) or confess "cannot create new varbind for $oid";
-	my $vb = SNMP::Class::Varbind->new($oid);
-	should(ref $vb,'SNMP::Class::Varbind');
+	my $vb = SNMP::Class::Varbind->new($oid) or confess "cannot create new varbind for $oid";
 
 	#create the bag
 	my $ret = SNMP::Class::ResultSet->new();
@@ -308,19 +245,12 @@ sub _walk:RESTICTED() {
 		#make sure nothing went wrong
 		confess $session{$id}->{ErrorStr} if ($session{$id}->{ErrorNum} != 0);
 
-		$logger->debug($vb->get_oid->to_string."=".$value." Object is ".$vb->get_object->to_string.",instance is ".$vb->get_instance_numeric.",type is ".$vb->get_type);
-
-		#handle some special types
-		#For example, a type of ENDOFMIBVIEW means we should stop
-		if($vb->get_type eq 'ENDOFMIBVIEW') {
-			$logger->debug("We should stop because an end of MIB View was encountered");
-			last LOOP;
-		}
+		$logger->debug($vb->get_oid->to_string."=".$value." Object is ".$vb->get_object->to_string.",instance is ".$vb->get_instance_numeric);
 
 		#make sure that we got a different oid than in the previous iteration
 		#(remember, the NetSNMP::OID has an overloaded '==' operator)
 		if($previous == $vb->get_oid) { 
-			confess "OID not increasing at ".$vb->get_oid->numeric." (".$vb->get_oid->to_string.")\n";
+			confess "OID not increasing at ".$vb->get_oid.". Previous oid was $previous\n";
 		}
 
 		#make sure we are still under the original $oid -- if not we are finished
@@ -369,7 +299,7 @@ sub AUTOMETHOD {
 	return sub {
 		if(wantarray) {
 			$logger->debug("$subname called in list context");
-			return @{$self->walk($subname)->varbinds};
+			return @{$self->walk($subname)->get_varbind_listref};
 		}
 		return $self->walk($subname);
 	}
